@@ -7,6 +7,13 @@ def has_sufficient_params(func):
         assert app_name is not None, "'app_name' not provided"
         assert model_name is not None, "'model_name' not provided"
 
-        return func(request, app_name, model_name, pk, *args, **kwargs)
+        return func(
+            request=request,
+            app_name=app_name,
+            model_name=model_name,
+            pk=pk,
+            *args,
+            **kwargs
+        )
 
     return wrapper
